@@ -42,12 +42,14 @@ template<class M, unsigned P, size_t S, bool MT>
 class LastGoodReply
 {
 public:
-    typedef M Move;
+    using Move = M;
+
 
     static const unsigned max_players = P;
 
     static const size_t hash_table_size = S;
 
+
     LastGoodReply();
 
     void init(PlayerInt nu_players);
@@ -109,19 +111,12 @@ template<class M, unsigned P, size_t S, bool MT>
 void LastGoodReply<M, P, S, MT>::init(PlayerInt nu_players)
 {
     for (PlayerInt i = 0; i < nu_players; ++i)
-        if (Move::null().to_int() == 0)
-        {
-            // Using memset is ok even if the elements are atomic because
-            // init() is used before the multi-threaded search starts.
-            memset(m_lgr1[i], 0, Move::range * sizeof(m_lgr1[i][0]));
-            memset(m_lgr2[i], 0, hash_table_size * sizeof(m_lgr2[i][0]));
-        }
-        else
-        {
-            fill(m_lgr1[i], m_lgr1[i] + Move::range, Move::null().to_int());
-            fill(m_lgr2[i], m_lgr2[i] + hash_table_size,
-                 Move::null().to_int());
-        }
+    {
+        for (typename Move::IntType j = 0; j < Move::range; ++j)
+            m_lgr1[i][j].store(Move::null().to_int(), memory_order_relaxed);
+        for (size_t j = 0; j < hash_table_size; ++j)
+            m_lgr2[i][j].store(Move::null().to_int(), memory_order_relaxed);
+    }
 }
 
 template<class M, unsigned P, size_t S, bool MT>
