@@ -17,7 +17,7 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-typedef uint_least32_t NodeIdx;
+using NodeIdx = uint_least32_t;
 
 //-----------------------------------------------------------------------------
 
@@ -28,9 +28,10 @@ template<typename M, typename F, bool MT>
 class Node
 {
 public:
-    typedef M Move;
+    using Move = M;
+
+    using Float = F;
 
-    typedef F Float;
 
     Node() = default;
 
@@ -40,19 +41,20 @@ public:
 
     /** Initialize the node.
         This function may not be called on a node that is already part of
-        the tree in multi-threaded mode.
-        The node may be initialized with values and counts greater zero
-        (prior knowledge) but even if it is initialized with count zero, it
-        must be initialized with a usable value (e.g. first play urgency for
-        inner nodes or tie value for the root node). */
-    void init(const Move& mv, Float value, Float count);
+        the tree in multi-threaded mode. */
+    void init(const Move& mv, Float value, Float count, Float move_prior);
 
     /** Initializes the root node.
         Does not initialize value and value count as they are not used for the
         root. */
     void init_root();
 
-    const Move& get_move() const;
+    const Move& get_move() const { return m_move; }
+
+    /** Prior value for the move.
+        This value is used in the exploration term, see description of class
+        SearchBase. */
+    Float get_move_prior() const { return m_move_prior; }
 
     /** Number of simulations that went through this node. */
     Float get_visit_count() const;
@@ -86,10 +88,8 @@ public:
         code. */
     void link_children_st(NodeIdx first_child, unsigned short nu_children);
 
-    void unlink_children();
-
-    /** Faster version of unlink_children() for single-threaded parts of the
-        code. */
+    /** Unlink children.
+        Only to be used in single-threaded parts of the code. */
     void unlink_children_st();
 
     void add_value(Float v, Float weight = 1);
@@ -112,6 +112,8 @@ private:
 
     Atomic<Float, MT> m_visit_count;
 
+    Float m_move_prior;
+
     Atomic<unsigned short, MT> m_nu_children;
 
     Move m_move;
@@ -154,6 +156,7 @@ void Node<M, F, MT>::copy_data_from(const Node& node)
         Atomic<Float, MT> m_value;
         Atomic<Float, MT> m_value_count;
         Atomic<Float, MT> m_visit_count;
+        Float m_move_prior;
         Atomic<unsigned short, MT> m_nu_children;
         Move m_move;
         NodeIdx m_first_child;
@@ -161,6 +164,7 @@ void Node<M, F, MT>::copy_data_from(const Node& node)
     static_assert(sizeof(Node) == sizeof(Dummy), "");
 
     m_move = node.m_move;
+    m_move_prior = node.m_move_prior;
     // Load/store relaxed (it wouldn't even need to be atomic) because this
     // function is only used before the multi-threaded search.
     m_value_count.store(node.m_value_count.load(memory_order_relaxed),
@@ -184,12 +188,6 @@ inline NodeIdx Node<M, F, MT>::get_first_child() const
     return m_first_child;
 }
 
-template<typename M, typename F, bool MT>
-inline auto Node<M, F, MT>::get_move() const -> const Move&
-{
-    return m_move;
-}
-
 template<typename M, typename F, bool MT>
 inline unsigned short Node<M, F, MT>::get_nu_children() const
 {
@@ -225,7 +223,8 @@ inline void Node<M, F, MT>::inc_visit_count()
 }
 
 template<typename M, typename F, bool MT>
-void Node<M, F, MT>::init(const Move& mv, Float value, Float count)
+void Node<M, F, MT>::init(const Move& mv, Float value, Float count,
+                          Float move_prior)
 {
     // The node is not yet visible to other threads because init() is called
     // before the children are linked to its parent with link_children()
@@ -233,6 +232,7 @@ void Node<M, F, MT>::init(const Move& mv, Float value, Float count)
     // Therefore, the most efficient way here is to initialize all values with
     // memory_order_relaxed.
     m_move = mv;
+    m_move_prior = move_prior;
     m_value_count.store(count, memory_order_relaxed);
     m_value.store(value, memory_order_relaxed);
     m_visit_count.store(0, memory_order_relaxed);
@@ -272,12 +272,6 @@ inline void Node<M, F, MT>::link_children_st(NodeIdx first_child,
     m_nu_children.store(nu_children, memory_order_relaxed);
 }
 
-template<typename M, typename F, bool MT>
-inline void Node<M, F, MT>::unlink_children()
-{
-    m_nu_children.store(0, memory_order_release);
-}
-
 template<typename M, typename F, bool MT>
 inline void Node<M, F, MT>::unlink_children_st()
 {
