@@ -22,13 +22,13 @@ using namespace std;
 //-----------------------------------------------------------------------------
 
 /** Dialog that asks the user to estimate his initial rating. */
-class InitialRatingDialog
+class InitialRatingDialog final
     : public QDialog
 {
     Q_OBJECT
 
 public:
-    InitialRatingDialog(QWidget* parent);
+    explicit InitialRatingDialog(QWidget* parent);
 
     int getRating() const;
 
