@@ -39,7 +39,8 @@ inline Float sigmoid(Float steepness, Float x)
 
 State::State(Variant initial_variant, const SharedConst& shared_const)
   : m_shared_const(shared_const),
-    m_bd(initial_variant)
+    m_bd(initial_variant),
+    m_prior_knowledge(m_bd)
 {
 }
 
@@ -266,7 +267,7 @@ void State::evaluate_multiplayer(array<Float, 6>& result)
     }
 }
 
-/** Evaluation function for Duo, Junior and Callisto Two-Player. */
+/** Evaluation function for game variants with 2 colors. */
 void State::evaluate_twocolor(array<Float, 6>& result)
 {
     LIBBOARDGAME_ASSERT(m_bd.get_nu_players() == 2);
@@ -326,8 +327,8 @@ Point State::find_best_starting_point(Color c) const
             if (y <= 3 || y >= geo.get_height() - 3 - 1)
                 continue;
         }
-        float px = static_cast<float>(geo.get_x(p));
-        float py = static_cast<float>(geo.get_y(p));
+        auto px = static_cast<float>(geo.get_x(p));
+        auto py = static_cast<float>(geo.get_y(p));
         float d = 0;
         for (Color i : Color::Range(m_nu_colors))
             for (Point pp : m_bd.get_starting_points(i))
@@ -335,8 +336,8 @@ Point State::find_best_starting_point(Color c) const
                 PointState s = m_bd.get_point_state(pp);
                 if (! s.is_empty())
                 {
-                    float ppx = static_cast<float>(geo.get_x(pp));
-                    float ppy = static_cast<float>(geo.get_y(pp));
+                    auto ppx = static_cast<float>(geo.get_x(pp));
+                    auto ppy = static_cast<float>(geo.get_y(pp));
                     float dx = ppx - px;
                     float dy = ratio * (ppy - py);
                     float weight = 1;
@@ -361,33 +362,37 @@ bool State::gen_children(Tree::NodeExpander& expander, Float root_val)
     Color to_play = m_bd.get_to_play();
     if (m_max_piece_size == 5)
     {
-        init_moves_without_gamma<5>(to_play);
-        return m_prior_knowledge.gen_children<5, 16>(m_bd, m_moves[to_play],
-                                                     m_is_symmetry_broken,
-                                                     expander, root_val);
+        if (! m_is_callisto)
+        {
+            init_moves_without_gamma<5, false>(to_play);
+            return m_prior_knowledge.gen_children<5, 16, false>(
+                        m_bd, m_moves[to_play], m_is_symmetry_broken,
+                        expander, root_val);
+        }
+        init_moves_without_gamma<5, true>(to_play);
+        return m_prior_knowledge.gen_children<5, 16, true>(
+                    m_bd, m_moves[to_play], m_is_symmetry_broken,
+                    expander, root_val);
     }
-    else if (m_max_piece_size == 6)
+    if (m_max_piece_size == 6)
     {
-        init_moves_without_gamma<6>(to_play);
-        return m_prior_knowledge.gen_children<6, 22>(m_bd, m_moves[to_play],
-                                                     m_is_symmetry_broken,
-                                                     expander, root_val);
+        init_moves_without_gamma<6, false>(to_play);
+        return m_prior_knowledge.gen_children<6, 22, false>(
+                    m_bd, m_moves[to_play], m_is_symmetry_broken, expander,
+                    root_val);
     }
-    else if (m_max_piece_size == 7)
+    if (m_max_piece_size == 7)
     {
-        init_moves_without_gamma<7>(to_play);
-        return m_prior_knowledge.gen_children<7, 12>(m_bd, m_moves[to_play],
-                                                     m_is_symmetry_broken,
-                                                     expander, root_val);
-    }
-    else
-    {
-        LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
-        init_moves_without_gamma<22>(to_play);
-        return m_prior_knowledge.gen_children<22, 44>(m_bd, m_moves[to_play],
-                                                      m_is_symmetry_broken,
-                                                      expander, root_val);
+        init_moves_without_gamma<7, false>(to_play);
+        return m_prior_knowledge.gen_children<7, 12, false>(
+                    m_bd, m_moves[to_play], m_is_symmetry_broken, expander,
+                    root_val);
     }
+    LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
+    init_moves_without_gamma<22, false>(to_play);
+    return m_prior_knowledge.gen_children<22, 44, false>(
+                m_bd, m_moves[to_play], m_is_symmetry_broken, expander,
+                root_val);
 }
 
 bool State::gen_playout_move_full(PlayerMove<Move>& mv)
@@ -488,12 +493,13 @@ inline const PieceMap<bool>& State::get_is_piece_considered(Color c) const
 
 /** Initializes and returns m_pieces_considered if not all pieces are
     considered, otherwise m_bd.get_pieces_left(c) is returned. */
+template<bool IS_CALLISTO>
 inline const Board::PiecesLeftList& State::get_pieces_considered(Color c)
 {
     auto is_piece_considered = m_is_piece_considered[c];
     auto& pieces_left = m_bd.get_pieces_left(c);
     if (is_piece_considered == &m_shared_const.is_piece_considered_all
-            && ! m_is_callisto)
+            && ! IS_CALLISTO)
         return pieces_left;
     unsigned n = 0;
     for (Piece piece : pieces_left)
@@ -511,7 +517,7 @@ inline Float State::get_quality_bonus(Color c, Float result, Float score)
     Float bonus = 0;
 
     // Game length
-    Float l = static_cast<Float>(m_bd.get_nu_moves());
+    auto l = static_cast<Float>(m_bd.get_nu_moves());
     m_stat_len.add(l);
     Float var = m_stat_len.get_variance();
     if (var > 0)
@@ -537,10 +543,10 @@ inline Float State::get_quality_bonus_attach_twocolor()
     int n = m_bd.get_attach_points(Color(0)).size()
             - m_bd.get_attach_points(Color(1)).size();
     for (Point p : m_bd.get_attach_points(Color(0)))
-        n -= m_bd.is_forbidden(p, Color(0));
+        n -= static_cast<int>(m_bd.is_forbidden(p, Color(0)));
     for (Point p : m_bd.get_attach_points(Color(1)))
-        n += m_bd.is_forbidden(p, Color(1));
-    Float attach = static_cast<Float>(n);
+        n += static_cast<int>(m_bd.is_forbidden(p, Color(1)));
+    auto attach = static_cast<Float>(n);
     m_stat_attach.add(attach);
     auto var = m_stat_attach.get_variance();
     if (var > 0)
@@ -559,14 +565,14 @@ inline Float State::get_quality_bonus_attach_multicolor()
             - m_bd.get_attach_points(Color(1)).size()
             - m_bd.get_attach_points(Color(3)).size();
     for (Point p : m_bd.get_attach_points(Color(0)))
-        n -= m_bd.is_forbidden(p, Color(0));
+        n -= static_cast<int>(m_bd.is_forbidden(p, Color(0)));
     for (Point p : m_bd.get_attach_points(Color(2)))
-        n -= m_bd.is_forbidden(p, Color(2));
+        n -= static_cast<int>(m_bd.is_forbidden(p, Color(2)));
     for (Point p : m_bd.get_attach_points(Color(1)))
-        n += m_bd.is_forbidden(p, Color(1));
+        n += static_cast<int>(m_bd.is_forbidden(p, Color(1)));
     for (Point p : m_bd.get_attach_points(Color(3)))
-        n += m_bd.is_forbidden(p, Color(3));
-    Float attach = static_cast<Float>(n);
+        n += static_cast<int>(m_bd.is_forbidden(p, Color(3)));
+    auto attach = static_cast<Float>(n);
     m_stat_attach.add(attach);
     auto var = m_stat_attach.get_variance();
     if (var > 0)
@@ -695,7 +701,7 @@ void State::init_moves_with_gamma(Color c)
     auto& marker = m_marker[c];
     auto& moves = m_moves[c];
     marker.clear(moves);
-    auto& pieces = get_pieces_considered(c);
+    auto& pieces = get_pieces_considered<IS_CALLISTO>(c);
     if (m_bd.is_first_piece(c) && ! IS_CALLISTO)
         add_starting_moves<MAX_SIZE>(c, pieces, true, moves);
     else
@@ -728,21 +734,21 @@ void State::init_moves_with_gamma(Color c)
     }
 }
 
-template<unsigned MAX_SIZE>
+template<unsigned MAX_SIZE, bool IS_CALLISTO>
 void State::init_moves_without_gamma(Color c)
 {
     m_is_piece_considered[c] = &get_is_piece_considered(c);
     auto& marker = m_marker[c];
     auto& moves = m_moves[c];
     marker.clear(moves);
-    auto& pieces = get_pieces_considered(c);
+    auto& pieces = get_pieces_considered<IS_CALLISTO>(c);
     auto& is_forbidden = m_bd.is_forbidden(c);
-    if (m_bd.is_first_piece(c) && ! (MAX_SIZE == 5 && m_is_callisto))
+    if (m_bd.is_first_piece(c) && ! (MAX_SIZE == 5 && IS_CALLISTO))
         add_starting_moves<MAX_SIZE>(c, pieces, false, moves);
     else
     {
         unsigned nu_moves = 0;
-        if (MAX_SIZE == 5 && m_is_callisto)
+        if (MAX_SIZE == 5 && IS_CALLISTO)
         {
             float total_gamma_dummy;
             add_callisto_one_piece_moves(c, false, total_gamma_dummy, moves,
@@ -777,7 +783,7 @@ void State::init_moves_without_gamma(Color c)
             != &m_shared_const.is_piece_considered_all)
     {
         m_force_consider_all_pieces = true;
-        init_moves_without_gamma<MAX_SIZE>(c);
+        init_moves_without_gamma<MAX_SIZE, IS_CALLISTO>(c);
     }
 }
 
@@ -801,43 +807,6 @@ void State::play_expanded_child(Move mv)
     }
 }
 
-void State::play_in_tree(Move mv)
-{
-    Color to_play = m_bd.get_to_play();
-    if (! mv.is_null())
-    {
-        LIBBOARDGAME_ASSERT(m_bd.is_legal(to_play, mv));
-        m_nu_passes = 0;
-        if (m_max_piece_size == 5)
-        {
-            m_bd.play<5, 16>(to_play, mv);
-            update_playout_features<5, 16>(to_play, mv);
-        }
-        else if (m_max_piece_size == 6)
-        {
-            m_bd.play<6, 22>(to_play, mv);
-            update_playout_features<6, 22>(to_play, mv);
-        }
-        else if (m_max_piece_size == 7)
-        {
-            m_bd.play<7, 12>(to_play, mv);
-            update_playout_features<7, 12>(to_play, mv);
-        }
-        else
-        {
-            m_bd.play<22, 44>(to_play, mv);
-            update_playout_features<22, 44>(to_play, mv);
-        }
-    }
-    else
-    {
-        ++m_nu_passes;
-        m_bd.set_to_play(to_play.get_next(m_nu_colors));
-    }
-    if (log_simulations)
-        LIBBOARDGAME_LOG(m_bd);
-}
-
 void State::start_search()
 {
     auto& bd = *m_shared_const.board;
@@ -947,7 +916,7 @@ void State::update_moves(Color c)
         }
 
     // Find new legal moves because of new pieces played by this color
-    auto& pieces = get_pieces_considered(c);
+    auto& pieces = get_pieces_considered<IS_CALLISTO>(c);
     auto& attach_points = m_bd.get_attach_points(c);
     auto begin = m_last_attach_points_end[c];
     auto end = attach_points.end();
