@@ -19,9 +19,9 @@ class FdInBuf
     : public streambuf
 {
 public:
-    FdInBuf(int fd, size_t buf_size = 1024);
+    explicit FdInBuf(int fd, size_t buf_size = 1024);
 
-    ~FdInBuf();
+    ~FdInBuf() override;
 
 protected:
     int_type underflow() override;
@@ -35,7 +35,7 @@ private:
 //-----------------------------------------------------------------------------
 
 /** Input stream from a file descriptor. */
-class FdInStream
+class FdInStream final
     : public istream
 {
 public:
@@ -56,7 +56,7 @@ public:
         : m_fd(fd)
     { }
 
-    ~FdOutBuf();
+    ~FdOutBuf() override;
 
 protected:
     int_type overflow(int_type c) override;
@@ -70,7 +70,7 @@ private:
 //-----------------------------------------------------------------------------
 
 /** Output stream from a file descriptor. */
-class FdOutStream
+class FdOutStream final
     : public ostream
 {
 public:
